import React, { useState } from "react";

import { addPost, addProposal } from "actions/posts";
import Button from "components/Button";
import ErrorMessage from "components/ErrorMessage";
import MarkdownEditor from "components/mde/MarkdownEditor";
import { useActionState } from "hooks";

const AddPostForm = ({ className }) => {
  const [text, setText] = useState("");
  const [type, setType] = useState("post");
  const [noTextError, setNoTextError] = useState(false);
  const [addingPost, addingPostError] = useActionState(addPost, {
    content: text,
  });
  const [addingProposal, addingProposalError] = useActionState(addPost, {
    content: text,
  });

  const onTextInput = (newText) => {
    setText(newText);

    if (newText !== "") {
      setNoTextError(false);
    }
  };

  const onAdd = async (evt) => {
    if (!!text) {
      const result = await (type === "post" ? addPost : addProposal).run({
        content: text,
      });

      if (!result.error) {
        setText("");
      }
    } else {
      setNoTextError(true);
    }
  };

  return (
    <div className={className}>
      {addingPostError && (
        <ErrorMessage>
          Při přidávání příspěvku došlo k problému: {addingPostError}.
        </ErrorMessage>
      )}
      {addingProposalError && (
        <ErrorMessage>
          Při přidávání příspěvku došlo k problému: {addingProposalError}.
        </ErrorMessage>
      )}

      <MarkdownEditor
        value={text}
        onChange={onTextInput}
        error={
          noTextError
            ? "Před přidáním příspěvku nezapomeňte vyplnit jeho obsah."
            : null
        }
        placeholder="Vyplňte text vašeho příspěvku"
        toolbarCommands={[
          ["header", "bold", "italic", "strikethrough"],
          ["link", "quote"],
          ["unordered-list", "ordered-list"],
        ]}
      />

      <div className="form-field" onChange={(evt) => setType(evt.target.value)}>
        <div className="form-field__wrapper">
          <div className="radio form-field__control">
            <label>
              <input type="radio" name="postType" value="post" defaultChecked />
              <span>
                Přidávám <strong>běžný příspěvek</strong>
              </span>
            </label>
          </div>

          <div className="radio form-field__control">
            <label>
              <input type="radio" name="postType" value="procedure-proposal" />
              <span>
                Přidávám <strong>návrh postupu</strong>
              </span>
            </label>
          </div>
        </div>
      </div>

      <div className="space-x-4">
        <Button
          onClick={onAdd}
          disabled={addingPost || addingProposal}
          loading={addingPost || addingProposal}
          fullwidth
          hoverActive
        >
          {type === "post" && "Přidat příspěvek"}
          {type === "procedure-proposal" && "Navrhnout postup"}
        </Button>

        <span className="text-sm text-grey-200 hidden lg:inline">
          Pro pokročilejší formátování můžete používat{" "}
          <a
            href="https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet"
            className="underline"
            target="_blank"
            rel="noreferrer noopener"
          >
            Markdown
          </a>
          .
        </span>
      </div>
    </div>
  );
};

export default AddPostForm;
